/**
 * @fileoverview Enforce img tag uses alt attribute.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var errorMessage = function errorMessage(type) {
  return type + ' elements must have an alt tag.';
};

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var typeCheck = ['img'].concat(context.options[0]);
      var nodeType = node.name.name;

      // Only check 'img' elements and custom types.
      if (typeCheck.indexOf(nodeType) === -1) {
        return;
      }

      var hasAltProp = (0, _hasAttribute2.default)(node.attributes, 'alt');

      // alt must have a value.
      if (hasAltProp === false || hasAltProp === null) {
        context.report({
          node: node,
          message: errorMessage(nodeType)
        });
      }
    }
  };
};

module.exports.schema = [{
  "oneOf": [{ "type": "string" }, {
    "type": "array",
    "items": {
      "type": "string"
    },
    "minItems": 1,
    "uniqueItems": true
  }]
}];