/**
 * @fileoverview Enforce label tags have htmlFor attribute.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var errorMessage = 'Form controls using a label to identify them must be ' + 'programmatically associated with the control using htmlFor';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var typeCheck = ['label'].concat(context.options[0]);
      var nodeType = node.name.name;

      // Only check 'label' elements and custom types.
      if (typeCheck.indexOf(nodeType) === -1) {
        return;
      }

      var hasHtmlForAttr = (0, _hasAttribute2.default)(node.attributes, 'htmlFor');

      if (hasHtmlForAttr === false) {
        context.report({
          node: node,
          message: errorMessage
        });
      }
    }
  };
};

module.exports.schema = [{
  "oneOf": [{ "type": "string" }, {
    "type": "array",
    "items": {
      "type": "string"
    },
    "minItems": 1,
    "uniqueItems": true
  }]
}];