'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _buildTemplateLiteral = require('./buildTemplateLiteral');

var _buildTemplateLiteral2 = _interopRequireDefault(_buildTemplateLiteral);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns the value of a given attribute.
 * Different types of attributes have their associated
 * values in different properties on the object.
 *
 * This function should return the most *closely* associated
 * value with the intention of the JSX.
 */
var getAttributeValue = function getAttributeValue(attribute) {
  if (attribute.value === null) {
    return null;
  } else if (attribute.type === 'JSXAttribute') {

    if (attribute.value.type === 'Literal') {
      return attribute.value.value === "" ? undefined : attribute.value.value;
    } else if (attribute.value.type === 'JSXExpressionContainer') {
      var expression = attribute.value.expression;

      switch (expression.type) {
        case 'Literal':
          return expression.value === "" ? undefined : expression.value;
        case 'TemplateLiteral':
          return (0, _buildTemplateLiteral2.default)(expression);
        case 'Identifier':
          return expression.name == 'undefined' ? undefined : expression.name;
        case 'ArrowFunctionExpression':
        case 'FunctionExpression':
          return function () {
            return void 0;
          };
        default:
          return undefined;
      }
    }
  }

  return undefined;
};

exports.default = getAttributeValue;