'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _getAttributeValue = require('./getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns the value of the attribute or false, indicating the attribute
 * is not present on the JSX opening element. This skips over spread attributes
 * as the purpose of this linter is to do hard checks of explicit JSX props.
 *
 * This treats undefined values as missing props, as they will not be used for
 * rendering on elements that live closest to the DOM (pure html JSX elements).
 */
var hasAttribute = function hasAttribute(attributes, attribute) {
  var value = false;

  var hasAttr = attributes.some(function (attr) {
    // If the attributes contain a spread attribute, then skip.
    if (attr.type === 'JSXSpreadAttribute') {
      return false;
    }

    // Normalize.
    if (attr.name.name.toUpperCase() === attribute.toUpperCase()) {
      value = (0, _getAttributeValue2.default)(attr);

      // If the value is undefined, it doesn't really have the attribute.
      return value !== undefined;
    }

    return false;
  });

  return hasAttr ? value : false;
};

exports.default = hasAttribute;